profile\_photo.utils.aws package
================================

Submodules
----------

profile\_photo.utils.aws.client\_cache module
---------------------------------------------

.. automodule:: profile_photo.utils.aws.client_cache
   :members:
   :undoc-members:
   :show-inheritance:

profile\_photo.utils.aws.rekognition module
-------------------------------------------

.. automodule:: profile_photo.utils.aws.rekognition
   :members:
   :undoc-members:
   :show-inheritance:

profile\_photo.utils.aws.rekognition\_models module
---------------------------------------------------

.. automodule:: profile_photo.utils.aws.rekognition_models
   :members:
   :undoc-members:
   :show-inheritance:

profile\_photo.utils.aws.rekognition\_utils module
--------------------------------------------------

.. automodule:: profile_photo.utils.aws.rekognition_utils
   :members:
   :undoc-members:
   :show-inheritance:

profile\_photo.utils.aws.s3 module
----------------------------------

.. automodule:: profile_photo.utils.aws.s3
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: profile_photo.utils.aws
   :members:
   :undoc-members:
   :show-inheritance:
